@@ -1,5 +1,5 @@
 import datetime
-from typing import TypeVar, Any
+from typing import Any, TypeVar
 
 from boltons.iterutils import remap
 
