@@ -1,6 +1,7 @@
+import json
 from dataclasses import dataclass, field
 from functools import reduce
-from pathlib import Path, PosixPath
+from pathlib import Path
 from typing import Iterable, List, Optional, TextIO, Type
 
 from documented import DocumentedError
@@ -10,6 +11,7 @@ from iolanta.loaders.base import Loader
 from iolanta.models import LDContext, LDDocument, Quad
 from iolanta.parsers.base import Parser
 from iolanta.parsers.json import JSON
+from iolanta.parsers.markdown import Markdown
 from iolanta.parsers.yaml import YAML
 from rdflib import URIRef
 from urlpath import URL
@@ -59,22 +61,33 @@ class LocalFile(Loader):
         'context.yaml',
         'context.json',
     ])
-    default_context: Optional[LDContext] = None
+    default_context: Optional[LDContext] = field(default=None, repr=False)
 
     def choose_parser_class(self, url: URL) -> Type[Parser]:
+        """
+        Choose parser class based on file extension.
+
+        FIXME this is currently hard coded; need to change to a more extensible
+          mechanism.
+        """
         if url.suffix == '.yaml':
             return YAML
 
         elif url.suffix == '.json':
             return JSON
 
+        elif url.suffix == '.md':
+            return Markdown
+
         raise ParserNotFound(path=url)
 
     def as_quad_stream(
         self,
         url: URL,
         iri: Optional[URIRef],
+        root_loader: Loader,
     ) -> Iterable[Quad]:
+        """Extract a sequence of quads from a local file."""
         if url.stem == 'context':
             raise IsAContext(path=url)
 
@@ -87,11 +100,9 @@ class LocalFile(Loader):
                 raw_data=text_io,
                 iri=iri,
                 context=context,
+                root_loader=root_loader,
             )
 
-    def __call__(self, url: str):
-        pass
-
     def as_file(self, url: URL) -> TextIO:
         """Construct a file-like object."""
         path = url_to_path(url)
@@ -104,7 +115,7 @@ class LocalFile(Loader):
         iri: Optional[URIRef] = None,
     ) -> LDDocument:
         """As JSON-LD document."""
-        parser_class = self.choose_parser_class(url)
+        parser_class: Type[Parser] = self.choose_parser_class(url)
         with url_to_path(url).open() as text_io:
             document = parser_class().as_jsonld_document(text_io)
 
