@@ -13,7 +13,13 @@ from rich.table import Table
 
 @typeclass
 def pretty_print_value(rdflib_value: Union[URIRef, Literal, BNode]) -> str:
-    ...
+    """Pretty print a value for a table in CLI."""
+
+
+@pretty_print_value.instance(type(None))
+def _pretty_print_none(none_value):
+    """Format None."""
+    return f'∅ {none_value}'
 
 
 @pretty_print_value.instance(URIRef)
