@@ -1,9 +1,8 @@
 from mkdocs.config import load_config
 from more_itertools import consume
+from octadocs.cli import context, sparql
 from typer import Typer
 
-from octadocs.cli import sparql, context
-
 
 def generate_app() -> Typer:
     app = Typer()
