@@ -16,7 +16,7 @@ from iolanta.facets.by_instance import FindFacetByInstance
 from iolanta.facets.by_literal_datatype import FindFacetByLiteralDatatype
 from iolanta.facets.by_type import FindFacetByType
 from ldflex import LDFlex
-from octadocs.iolanta.errors import FacetNotCallable, FacetNotFound, FacetError
+from octadocs.iolanta.errors import FacetError, FacetNotCallable, FacetNotFound
 from octadocs.octiron import Octiron
 from rdflib import RDFS
 from rdflib.term import Literal, Node, URIRef
@@ -75,15 +75,16 @@ def render(
     )
 
     facet = facet(
-        octiron=octiron,
         iri=node,
+        octiron=octiron,
+        environment=facet_search_attempt.environment,
     )
 
     if isinstance(facet, Facet):
         try:
-            return str(facet.render())
+            return facet.render()
 
-        except (FacetError, FacetNotFound):
+        except (FacetError, FacetNotFound):   # noqa: WPS329
             # Prevent nested `FacetError` exceptions.
             raise
 
@@ -228,7 +229,7 @@ class Render:
     def find_instance_types(self, node: URIRef) -> List[URIRef]:
         """Find types for particular node."""
         rows = self.ldflex.query(
-            '''
+            query_text='''
             SELECT ?type WHERE {
                 $node rdf:type ?type .
             }
