@@ -3,7 +3,6 @@ import textwrap
 from pathlib import Path
 
 import owlrl
-from octadocs.octiron.owlrl_named_graph import OWLRLExtensionNamedGraph
 from owlrl import OWLRL_Extension
 from rdflib import ConjunctiveGraph
 
@@ -13,14 +12,14 @@ logger = logging.getLogger(__name__)
 def apply_inference_owlrl(graph: ConjunctiveGraph) -> None:
     """Apply OWL RL inference rules."""
     logger.info('Inference: OWL RL started...')
-    owlrl.DeductiveClosure(OWLRLExtensionNamedGraph).expand(graph)
+    owlrl.DeductiveClosure(OWLRL_Extension).expand(graph)
     logger.info('Inference: OWL RL complete.')
 
 
 def apply_inference_sparql(
     inference_directory: Path,
     graph: ConjunctiveGraph,
-) -> None:
+) -> bool:
     """Apply custom SPARQL inference rules."""
     if inference_directory.is_dir():
         query_files = list(sorted(   # noqa: C413
@@ -34,7 +33,12 @@ def apply_inference_sparql(
             'No SPARQL inference files found at %s directory.',
             inference_directory,
         )
+        return False
 
+    logger.warning(
+        'SPARQL inference queries are an outdated feature. Files: %s',
+        query_files,
+    )
     for query_file in query_files:
         logger.info(
             'Inference: %s',
@@ -48,3 +52,5 @@ def apply_inference_sparql(
         ))
 
         graph.update(query_text)
+
+    return True
