@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Iterator, Optional, Any, Dict
+from typing import Any, Dict, Iterator, Optional
 
 import rdflib
 from octadocs.types import Context, Triple
