@@ -1,4 +1,4 @@
-from typing import Dict, Any
+from typing import Any, Dict
 
 from octadocs.pyld_document_loaders.models import JsonLDDocument
 
