@@ -1,11 +1,10 @@
 import logging
 from dataclasses import dataclass
-from typing import Dict, Any, List
-
-from pyld.jsonld import JsonLdError
+from typing import Any, Dict, List
 
 from octadocs.pyld_document_loaders.base import DocumentLoader
 from octadocs.pyld_document_loaders.models import JsonLDDocument
+from pyld.jsonld import JsonLdError
 
 logger = logging.getLogger(__name__)
 
