@@ -1,4 +1,4 @@
-from typing import TypedDict, Any, Dict, Optional
+from typing import Any, Dict, Optional, TypedDict
 
 
 class JsonLDDocument(TypedDict):
