@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Dict, Any
+from typing import Any, Dict
 
 from octadocs.pyld_document_loaders.base import DocumentLoader
 from octadocs.pyld_document_loaders.models import JsonLDDocument
