@@ -1,4 +1,4 @@
 from octadocs_adr.facets.adr_list import adr_list
-from octadocs_adr.facets.sidebar import page_sidebar, sidebar_property
+from octadocs_adr.facets.sidebar import PageSidebar, sidebar_property
 from octadocs_adr.facets.status import status
 from octadocs_adr.facets.status_class import status_class
