@@ -1,9 +1,8 @@
-from dominate.tags import a, span, img
+from dominate.tags import a, img, span
+from iolanta.facet import Facet
 from more_itertools import first
 from urlpath import URL
 
-from iolanta.facet import Facet
-
 
 class GithubRepo(Facet):
     """Render a link to a GitHub repo."""
