@@ -1,14 +1,13 @@
 from pathlib import Path
 from typing import Dict
 
-from mkdocs.plugins import BasePlugin
-from rdflib import URIRef, PROV
-from urlpath import URL
-
 from iolanta import as_document
 from iolanta.models import LDContext
+from mkdocs.plugins import BasePlugin
 from octadocs.mixins import OctadocsMixin
 from octadocs.types import OCTA
+from rdflib import PROV, URIRef
+from urlpath import URL
 
 
 class ProvenancePlugin(OctadocsMixin, BasePlugin):
